==> dde-network-core_1.0.7.1.orig.tar.xz: dde-network-core-1.0.7.1/dss-network-plugin/translations/dss-network-plugin_si.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="si" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>නව පණිවිඩ 1 ක් ලැබී ඇත</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 සම්බන්ධයි</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>රැහැන් සම්බන්ධතාවය</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>හොට්ස්පොට්</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>ප්රොටෝකෝලය</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>ආරක්ෂක වර්ගය</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>කලාපය</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>නාලිකාව</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>අතුරුමුහුණත</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>නෙට්මාස්ක්</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>ප්‍රාථමික DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>උපසර්ගය</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>වේගය</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>උපාංගය අක්‍රීය කර ඇත</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>ජාලගතව ඇතත් අන්තර්ජාල ප්‍රවේශය නොමැත</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>සම්බන්ධතා නොමැත</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ජාල කේබලය විසන්ධි කර ඇත</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>සම්බන්ධ වෙමින් පවතී</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>සත්‍යාපනය කිරීම</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP ලිපිනය ලබා ගැනීම</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>සම්බන්ධයි</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>විසන්ධි වි ඇත</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>අසමත් විය</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>රැහැන්ගත ජාලය</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>රැහැන්ගත ජාලය %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>රැහැන් රහිත ජාලය</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>රැහැන් රහිත ජාලය %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>උපාංගය අක්‍රීය කර ඇත</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ජාල කේබලය විසන්ධි කර ඇත</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>සම්බන්ධතා නොමැත</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>සම්බන්ධ වෙමින් පවතී</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>ජාලගතව ඇතත් අන්තර්ජාල ප්‍රවේශය නොමැත</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>රැහැන් සම්බන්ධතාවය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>රැහැන් සම්බන්ධතාවය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ජාලය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>ජාලය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ජාල සැකසුම්</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dss-network-plugin/translations/dss-network-plugin_si.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="si">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>නව පණිවිඩ 1 ක් ලැබී ඇත</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>රැහැන් රහිත ජාලය</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>රැහැන්ගත ජාලය</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 සම්බන්ධයි</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>සැඟවුණු ජාලයකට සම්බන්ධ වන්න</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>මුර පදය</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>සම්බන්ධ කරන්න</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>හොට්ස්පොට්</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>ප්රොටෝකෝලය</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>ආරක්ෂක වර්ගය</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>නාලිකාව</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>කලාපය</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>අතුරුමුහුණත</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>නෙට්මාස්ක්</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>දොරටුව-gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>ප්‍රාථමික DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>උපසර්ගය</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>වේගය</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>උපාංගය අක්‍රීය කර ඇත</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>ජාලගතව ඇතත් අන්තර්ජාල ප්‍රවේශය නොමැත</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>සම්බන්ධතා නොමැත</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ජාල කේබලය විසන්ධි කර ඇත</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>සම්බන්ධ වෙමින් පවතී</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>සත්‍යාපනය කිරීම</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP ලිපිනය ලබා ගැනීම</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>සම්බන්ධයි</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>විසන්ධි වි ඇත</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>අසමත් විය</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>රැහැන්ගත ජාලය</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>රැහැන්ගත ජාලය %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>රැහැන් රහිත ජාලය</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>රැහැන් රහිත ජාලය %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>උපාංගය අක්‍රීය කර ඇත</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ජාල කේබලය විසන්ධි කර ඇත</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>සම්බන්ධතා නොමැත</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>සම්බන්ධ වෙමින් පවතී</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>ජාලගතව ඇතත් අන්තර්ජාල ප්‍රවේශය නොමැත</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>රැහැන් සම්බන්ධතාවය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>රැහැන් සම්බන්ධතාවය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ජාලය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>ජාලය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ජාල සැකසුම්</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>රැහැන් සම්බන්ධතාවය</translation>
    </message>
</context>
</TS>
